'use strict';
const Schema = require('mongoose').Schema;
const moment = require('moment');
const metaPlugin = require('naf-framework-mongoose/lib/model/meta-plugin');
const { Secret } = require('naf-framework-mongoose/lib/model/schema');
const { ObjectId } = require('mongoose').Types;

// 专家表
const expert = {
  user_id: { type: ObjectId }, // 关联的personal的id
  education: { type: String, required: false, maxLength: 500 }, // 最高学历
  school: { type: String, required: false, maxLength: 500 }, // 毕业院校
  birthDate: { type: String, required: false, maxLength: 500 }, // 出生日期
  qqwx: { type: String, required: false, maxLength: 500 }, // qq&微信
  email: { type: String, required: false, maxLength: 500 }, // 邮箱
  company: { type: String, required: false, maxLength: 500 }, // 单位名称
  zwzc: { type: String, required: false, maxLength: 500 }, // 职务职称
  expertise: { type: String, required: false, maxLength: 500 }, // 擅长领域
  img_path: { type: String, required: false }, // 头像图片
  workexperience: { type: String, required: false, maxLength: 500 }, // 工作经历
  scientific: { type: String, required: false, maxLength: 500 }, // 科研综述
  undertakingproject: { type: String, required: false, maxLength: 500 }, // 承担项目
  scienceaward: { type: String, required: false, maxLength: 500 }, // 科技奖励
  social: { type: String, required: false, maxLength: 500 }, // 社会任职
  status: { type: String, required: false, default: '0', maxLength: 500 }, // 审核状态,0-注册,1-通过,2-拒绝
  major: { type: String, required: false, maxLength: 200 }, // 专业
  card: { type: String, required: false, maxLength: 200 }, // 身份证号

  isdel: { type: String, required: false, default: '0' }, // 0=>未删除;1=>已删除
  remark: { type: String, maxLength: 200 },
  create_time: {
    type: String,
    default: moment().format('YYYY-MM-DD HH:mm:ss'),
  },
};
const schema = new Schema(expert, { toJSON: { virtuals: true } });
schema.index({ id: 1 });
schema.index({ phone: 1 });
schema.index({ code: 1 });
schema.index({ status: 1 });
schema.index({ 'meta.createdAt': 1 });
schema.plugin(metaPlugin);
module.exports = app => {
  const { mongoose } = app;
  return mongoose.model('Expert', schema, 'expert');
};
